@@ -22,7 +22,22 @@ $LOAD_PATH.unshift(mkmf_gnome2_dir.to_s)
 module_name = "gio2"
 package_id = "gio-2.0"
 
-require 'mkmf-gnome2'
+begin
+  require 'mkmf-gnome2'
+rescue LoadError
+  require 'rubygems'
+  gem 'glib2'
+  require 'mkmf-gnome2'
+end
+
+["glib2"].each do |package|
+  directory = "#{package}#{version_suffix}"
+  build_dir = "#{directory}/tmp/#{RUBY_PLATFORM}/#{package}/#{RUBY_VERSION}"
+  add_depend_package(package, "#{directory}/ext/#{package}",
+                     top_dir.to_s,
+                     :top_build_dir => top_build_dir.to_s,
+                     :target_build_dir => build_dir)
+end
 
 win32 = setup_win32(module_name, base_dir)
 
@@ -36,15 +51,6 @@ PKGConfig.have_package('gobject-2.0') or exit 1
 
 have_func('rb_exec_recursive')
 
-["glib2"].each do |package|
-  directory = "#{package}#{version_suffix}"
-  build_dir = "#{directory}/tmp/#{RUBY_PLATFORM}/#{package}/#{RUBY_VERSION}"
-  add_depend_package(package, "#{directory}/ext/#{package}",
-                     top_dir.to_s,
-                     :top_build_dir => top_build_dir.to_s,
-                     :target_build_dir => build_dir)
-end
-
 def try_compiler_option(opt, &block)
   checking_for "#{opt} option to compiler" do
     $CFLAGS += " #{opt}" if try_compile '', opt, &block
