@@ -23,7 +23,38 @@ $LOAD_PATH.unshift(mkmf_gnome2_dir.to_s)
 module_name = "gtk2"
 package_id = "gtk+-2.0"
 
-require 'mkmf-gnome2'
+begin
+  require 'mkmf-gnome2'
+rescue LoadError
+  require 'rubygems'
+  gem 'glib2'
+  require 'mkmf-gnome2'
+end
+
+have_func("rb_errinfo")
+
+["glib2", "atk", "pango", "gdk_pixbuf2"].each do |package|
+  directory = "#{package}#{version_suffix}"
+  build_dir = "#{directory}/tmp/#{RUBY_PLATFORM}/#{package}/#{RUBY_VERSION}"
+  add_depend_package(package, "#{directory}/ext/#{package}",
+                     top_dir.to_s,
+                     :top_build_dir => top_build_dir.to_s,
+                     :target_build_dir => build_dir)
+end
+
+rcairo_options = {}
+rcairo_source_dir_names = ["rcairo"]
+if /mingw|cygwin|mswin32/ =~ RUBY_PLATFORM
+  rcairo_source_dir_names.unshift("rcairo.win32")
+end
+rcairo_source_dir_names.each do |rcairo_source_dir_name|
+  rcairo_source_dir = top_dir.parent.expand_path + rcairo_source_dir_name
+  if rcairo_source_dir.exist?
+    rcairo_options[:rcairo_source_dir] = rcairo_source_dir.to_s
+    break
+  end
+end
+check_cairo(rcairo_options)
 
 setup_win32(module_name, base_dir)
 
@@ -69,31 +100,6 @@ if target != "win32" and PKGConfig.have_package('gtk+-unix-print-2.0')
   $defs.push("-DHAVE_GTK_UNIX_PRINT")
 end
 
-have_func("rb_errinfo")
-
-options = {}
-rcairo_source_dir_names = ["rcairo"]
-if /mingw|cygwin|mswin32/ =~ RUBY_PLATFORM
-  rcairo_source_dir_names.unshift("rcairo.win32")
-end
-rcairo_source_dir_names.each do |rcairo_source_dir_name|
-  rcairo_source_dir = top_dir.parent.expand_path + rcairo_source_dir_name
-  if rcairo_source_dir.exist?
-    options[:rcairo_source_dir] = rcairo_source_dir.to_s
-    break
-  end
-end
-check_cairo(options)
-
-["glib2", "pango"].each do |package|
-  directory = "#{package}#{version_suffix}"
-  build_dir = "#{directory}/tmp/#{RUBY_PLATFORM}/#{package}/#{RUBY_VERSION}"
-  add_depend_package(package, "#{directory}/ext/#{package}",
-                     top_dir.to_s,
-                     :top_build_dir => top_build_dir.to_s,
-                     :target_build_dir => build_dir)
-end
-
 create_pkg_config_file("Ruby/GTK2", package_id, ruby_gnome2_version)
 
 class InitCreator
@@ -112,7 +118,7 @@ class InitCreator
     except_targets = ["Init_gtk2()", "Init_gtk_gdk()", "Init_gtk_gtk()"]
     @targets.each do |target|
       target.each_line do |line|
-        if /^(Init_.*\(\))(.*)/ =~ line
+        if /^(Init_.*\((?:void)?\))(.*)/ =~ line
           init = $1
           unless except_targets.include?(init)
             flag = $2
@@ -130,11 +136,21 @@ class InitCreator
       end
     end
 
+    inits[""] = inits[""].sort_by do |value|
+      if value == "Init_gtk_gdk_draw()"
+        inits[""].size * 2
+      elsif value == "Init_gtk_gdk_gc()"
+        -inits[""].size
+      else
+        inits[""].index(value)
+      end
+    end
+
     print_data(inits, "", nil, true)
     print_data(inits, "GTK_DISABLE_DEPRECATED", "ifndef", true)
     print_data(inits, "GTK_ENABLE_BROKEN", "ifdef", true)
 
-    print "void Init_gtk_inits()\n"
+    print "void Init_gtk_inits(void)\n"
     print "{\n"
     print_data(inits, "", nil)
     print_data(inits, "GTK_DISABLE_DEPRECATED", "ifndef")
@@ -151,14 +167,13 @@ class InitCreator
       print "##{defs} #{type}\n" if defs
       sorted_array = array[type].dup
       dependencies.each do |key, values|
-        key_index = sorted_array.index(key)
-        values.each do |value|
-          value_index = sorted_array.index(value)
-          next if value_index.nil?
-          sorted_array.delete(value)
-          sorted_array[key_index - 1, 0] = value
-          key_index = sorted_array.index(key)
+        next unless sorted_array.include?(key)
+        sorted_array.delete(key)
+        value_indexes = values.collect do |value|
+          sorted_array.index(value)
         end
+        max_value_index = value_indexes.compact.max
+        sorted_array[max_value_index + 1, 0] = key
       end
       sorted_array.each do |val|
         print "#{extern_def}   #{val};\n"
